@@ -97,13 +97,6 @@ class ScenarioBase(ABC):
         scenario_params.data_params = cls.data_cls().get_params_cls()()
         return scenario_params
 
-    @classmethod
-    def default_trainer_params(cls) -> 'TrainerParams':
-        trainer_params = cls.trainer_cls().get_params_cls()()
-        trainer_params.scenario_params = cls.default_params()
-        return trainer_params
-
-
     @classmethod
     def params_from_dict(cls, d: dict) -> ScenarioBaseParams:
         params: ScenarioBaseParams = cls.get_params_cls().from_dict(d)
@@ -111,13 +104,6 @@ class ScenarioBase(ABC):
         params.data_params = cls.data_cls().get_params_cls().from_dict(d['data_params'])
         return params
 
-    @classmethod
-    def trainer_params_from_dict(cls, d: dict) -> 'TrainerParams':
-        scenario_params = cls.params_from_dict(d['scenario_params'])
-        trainer_params = cls.trainer_cls().get_params_cls().from_dict(d)
-        trainer_params.scenario_params = scenario_params
-        return trainer_params
-
     @classmethod
     def from_path(cls, path: str) -> Tuple[Type['ScenarioBase'], ScenarioBaseParams]:
         trainer_params_json_path = os.path.join(path, 'trainer_params.json')
@@ -260,41 +246,38 @@ class ScenarioBase(ABC):
             self._export_resources(path, scenario_params_dict)
 
         # Export frozen model
-        if self._params.export_frozen:
-            full_model_func = tf.function(lambda x: self._keras_predict_model(x))
-            full_model_concrete = full_model_func.get_concrete_function(self._keras_predict_model.input)
-            # lower_control_flow=True enables tf1 compatibility by disabling tf2 control flow for ops like if/while
-            frozen_func = convert_variables_to_constants_v2(full_model_concrete, lower_control_flow=True)
-            frozen_func.graph.as_graph_def()
-            path_frozen = os.path.join(path, self._params.frozen_dir_)
-            os.makedirs(path_frozen, exist_ok=True)
-            tf.io.write_graph(graph_or_graph_def=frozen_func.graph,
-                              logdir=path_frozen,
-                              name=self._params.frozen_filename_,
-                              as_text=False)
+        full_model_func = tf.function(lambda x: self._keras_predict_model(x))
+        full_model_concrete = full_model_func.get_concrete_function(self._keras_predict_model.input)
+        # lower_control_flow=True enables tf1 compatibility by disabling tf2 control flow for ops like if/while
+        frozen_func = convert_variables_to_constants_v2(full_model_concrete, lower_control_flow=True)
+        frozen_func.graph.as_graph_def()
+        path_frozen = os.path.join(path, 'frozen')
+        os.makedirs(path_frozen, exist_ok=True)
+        id_frozen = 'frozen_model.pb'
+        tf.io.write_graph(graph_or_graph_def=frozen_func.graph,
+                          logdir=path_frozen,
+                          name=id_frozen,
+                          as_text=False)
 
         # Export serve models
-        if self._params.export_serve:
-            for label, export_graph in self._export_graphs.items():
-                if label == 'default':
-                    path_serve = os.path.join(path, self._params.default_serve_dir_)  # default model handled separately
-                else:
-                    path_serve = os.path.join(path, self._params.additional_serve_dir_, label)
-                os.makedirs(os.path.dirname(path_serve), exist_ok=True)
-                export_graph.model.save(path_serve, include_optimizer=False)
+        for label, export_graph in self._export_graphs.items():
+            if label == 'default':
+                path_serve = os.path.join(path, 'serve')  # default model handled separately
+            else:
+                path_serve = os.path.join(path, 'additional', label)
+            os.makedirs(path_serve, exist_ok=True)
+            export_graph.model.save(path_serve, include_optimizer=False)
 
-
-        if self._params.export_net_config_:
-            with open(os.path.join(path, self._params.net_config_filename_), 'w') as f:
-                json.dump(self.net_config().to_dict(), f, indent=2)
+        with open(os.path.join(path, 'net_config.json'), 'w') as f:
+            json.dump(self.net_config().to_dict(), f, indent=2)
 
         if trainer_params_dict:
-            params_path = os.path.join(path, self._params.trainer_params_filename_)
+            params_path = os.path.join(path, 'trainer_params.json')
             logger.debug("Storing trainer params to '{}'".format(params_path))
             with open(params_path, 'w') as f:
                 json.dump(trainer_params_dict, f, indent=2)
         else:
-            params_path = os.path.join(path, self._params.scenario_params_filename_)
+            params_path = os.path.join(path, 'scenario_params.json')
             with open(params_path, 'w') as f:
                 json.dump(scenario_params_dict, f, indent=2)
 
@@ -441,13 +424,14 @@ class ScenarioBase(ABC):
             # see setup_training
             # regroup data for training into all as input, and only loss and metrics as output
             # this is required to allow for custom losses with multiple inputs
+            ones_batched = [1] * batch_size
             if self._keras_train_model:
-                step_epoch = {'step': [self._keras_train_model.optimizer.iterations] * batch_size,
-                              'epoch': [self._keras_train_model.optimizer.iterations // steps_per_epoch] * batch_size}
+                step_epoch = {'step': ones_batched * self._keras_train_model.optimizer.iterations,
+                              'epoch': ones_batched * self._keras_train_model.optimizer.iterations // steps_per_epoch}
             else:
                 # No train model exists, this happens on model debug
-                step_epoch = {'step': [0] * batch_size,
-                              'epoch': [0] * batch_size}
+                step_epoch = {'step': ones_batched * 0,
+                              'epoch': ones_batched * 0}
             wrapped_inputs = {**inputs, **targets, **step_epoch}
             wrapped_targets = {**{l: [0] * batch_size for l in
                                   self._keras_model_data.loss_names + self._keras_model_data.extended_metric_names},
